/*
 * Calcoo: main.c
 *
 * Copyright (C) 2001, 2002 Alexei Kaminski
 *
 */

#include <gtk/gtk.h>

#include "c_headers.h"
#include "b_headers.h"

int main (int argc, char *argv[])
{
	gtk_init(&argc, &argv); 

	if (argc > 1 ) {
		process_options(argv[1]);
		return 0;
	}
	
     	create_body(); 

      	init_cpu();   

	load_options();

	gtk_main();

	return 0;
}

